[Gsll-devel] unicode in rng-types.lisp
Leo
sdl.web at gmail.com
Mon May 24 11:14:45 UTC 2010
Hello,
SBCL failed to start because of file rng-types.lisp contains some non
ascii names. I am using 1.0.34 on linux.
These default coding systems were tried to encode text
in the buffer `rng-types.lisp':
(us-ascii-unix (9359 . 252))
However, each of them encountered characters it couldn't encode:
us-ascii-unix cannot encode these: ü
Click on a character (or switch to this window by `C-x o'
and select the characters by RET) to jump to the place it appears,
where `C-u C-x =' will give information about it.
Leo
diff --git a/random/rng-types.lisp b/random/rng-types.lisp
index cc3b83e..7dc12dd 100644
--- a/random/rng-types.lisp
+++ b/random/rng-types.lisp
@@ -182,7 +182,7 @@
(def-rng-type +ranlux+ ; FDL
"The ranlux generator is an implementation of the original
- algorithm developed by Lüscher. It uses a
+ algorithm developed by Luscher. It uses a
lagged-fibonacci-with-skipping algorithm to produce ``luxury random
numbers''. It is a 24-bit generator, originally designed for
single-precision IEEE floating point numbers. This implementation is
@@ -192,23 +192,23 @@
The period of the generator is about
10^171. The algorithm has mathematically proven properties and
it can provide truly decorrelated numbers at a known level of
- randomness. The default level of decorrelation recommended by Lüscher
+ randomness. The default level of decorrelation recommended by Luscher
is provided by this generator, while *ranlux389*
gives the highest level of randomness, with all 24 bits decorrelated.
Both types of generator use 24 words of state per generator.
For more information see,
- M. Lüscher, ``A portable high-quality random number generator for
+ M. Luscher, ``A portable high-quality random number generator for
lattice field theory calculations'', Computer Physics
Communications, 79 (1994) 100--110.
F. James, ``RANLUX: A Fortran implementation of the high-quality
- pseudo-random number generator of Lüscher'', Computer Physics
+ pseudo-random number generator of Luscher'', Computer Physics
Communications, 79 (1994) 111--114.")
(def-rng-type +ranlux389+)
(def-rng-type +ranlxs0+
"This generator is a second-generation version of the
*ranlux* algorithm of Lüscher, which produces ``luxury random
numbers''. This generator provides single precision output (24 bits) at
three luxury levels *ranlxs0*, *ranlxs1* and *ranlxs2*.
It uses double-precision floating point arithmetic internally and can be
@@ -192,23 +192,23 @@
(def-rng-type +ranlxs0+
"This generator is a second-generation version of the
- *ranlux* algorithm of Lüscher, which produces ``luxury random
+ *ranlux* algorithm of Luscher, which produces ``luxury random
numbers''. This generator provides single precision output (24 bits) at
three luxury levels *ranlxs0*, *ranlxs1* and *ranlxs2*.
--
CCL-USER> (if you fail to plan (plan to fail))
More information about the gsll-devel
mailing list